@@ -171,6 +171,12 @@
 # define ntoh64(x) (x)
 #endif
 
+#ifdef WIN32
+#define FMT_LLX "%I64x"
+#else
+#define FMT_LLX "%llx"
+#endif
+
 /************************************************************************
  * Structurs
  ***********************************************************************/
@@ -955,16 +961,16 @@ static void print_info(htntlm_t *hook) {
   }
 
   if (hook->challenge) {
-    apr_file_printf(hook->out, "challenge: %llx\n", hook->challenge);
+    apr_file_printf(hook->out, "challenge: " FMT_LLX "\n", hook->challenge);
   }
 
   if (hook->client_challenge) {
-    apr_file_printf(hook->out, "client challenge: %llx\n", 
+    apr_file_printf(hook->out, "client challenge: " FMT_LLX "\n", 
 	            hook->client_challenge);
   }
   
   if (hook->context) {
-    apr_file_printf(hook->out, "context: %llx\n", hook->context);
+    apr_file_printf(hook->out, "context: " FMT_LLX "\n", hook->context);
   }
 
   if (hook->target_info) {
@@ -1685,15 +1691,15 @@ int main(int argc, const char *const argv[]) {
     RAND_pseudo_bytes((char *)&hook->client_challenge, sizeof(hook->client_challenge));
   }
   else {
-    sscanf(c_chl_str, "%llx", &hook->client_challenge);
+    sscanf(c_chl_str, FMT_LLX, &hook->client_challenge);
   }
   
   if (chl_str) {
-    sscanf(chl_str, "%llx", &hook->challenge);
+    sscanf(chl_str, FMT_LLX, &hook->challenge);
   }
   
   if (ctx_str) {
-    sscanf(chl_str, "%llx", &hook->context);
+    sscanf(chl_str, FMT_LLX, &hook->context);
   }
   
   if (hook->resp & HTNTLM_RESP_LM) {
