@@ -340,15 +340,8 @@ static apr_status_t wait_request(worker_t * worker, request_t *r) {
   else if ((val = apr_table_get(r->headers, "Transfer-Encoding"))) {
     status = transfer_enc_reader(sockreader, &r->body, &r->len, val);
   }
-  else if ((val = apr_table_get(r->headers, "Encapsulated"))) {
-    status = encapsulated_reader(sockreader, &r->body, &r->len, val,
-	                         apr_table_get(r->headers, "Preview"));
-  }
-  else if ((val = apr_table_get(r->headers, "Connection"))) {
-    status = eof_reader(sockreader, &r->body, &r->len, val);
-  }
 out_err:
-  return status;
+  return APR_SUCCESS;
 }
 
 /**
@@ -492,7 +485,7 @@ static apr_status_t do_request_line(self_t *self, worker_t *worker, apr_pool_t *
     //__GET /tt-nas-webui/styles/ttnas/layo...    -> replace /tt-nas-webui with variable
     tmp = apr_strtok(request_line, " /", &last);
     apr_strtok(NULL, "/", &last);
-    request_line = apr_pstrcat(worker->ptmp, tmp, " $",self->uri_var, "/", last, NULL);
+    request_line = apr_pstrcat(worker->pbody, tmp, " $",self->uri_var, "/", last, NULL);
   }  
   if (write) {
     apr_file_printf(self->ofp, "\n__%s", request_line); 
@@ -559,7 +552,7 @@ static apr_status_t do_headers(self_t *self, worker_t *worker, apr_pool_t *p,
 	else if (strcasecmp(e[i].key, "Cookie") == 0) {
 	  if (!(self->flags & SELF_FLAGS_SKIP_COOKIE_FIRST_TIME)) {
 	    apr_file_printf(self->ofp, "\n__Cookie: ");
-	    cookie = apr_pstrdup(worker->ptmp, e[i].val);
+	    cookie = apr_pstrdup(worker->pbody, e[i].val);
 	    cookie = apr_strtok(cookie, ";", &last);
 	    while (cookie) {
 	      /* split key from key=val */
@@ -567,11 +560,11 @@ static apr_status_t do_headers(self_t *self, worker_t *worker, apr_pool_t *p,
 	      while (*key == ' ') ++key;
 	      val = apr_strtok(NULL, "=", &ignore);
 	      if (val) {
-		cookie_val = apr_psprintf(worker->ptmp, "%s=$%s%s", 
+		cookie_val = apr_psprintf(worker->pbody, "%s=$%s%s", 
 		                          key, self->cookie_pre, key);
 	      }
 	      else {
-		cookie_val = apr_psprintf(worker->ptmp, "%s", key);
+		cookie_val = apr_psprintf(worker->pbody, "%s", key);
 	      }
 	      /* get next one here so we can detect last one in the next if cond */
 	      cookie = apr_strtok(NULL, ";", &last);
@@ -664,7 +657,7 @@ static apr_status_t do_body(self_t *self, worker_t *worker, apr_pool_t *p,
       }
 
       if (chunked) { 
-	line = apr_psprintf(worker->pool, "%x\r\n", len);
+	line = apr_psprintf(worker->pbody, "%x\r\n", len);
 	if ((status = worker_socket_send(worker, line, strlen(line))) != APR_SUCCESS) {
 	  return status;
 	}
@@ -811,13 +804,17 @@ static void *APR_THREAD_FUNC proxy_thread(apr_thread_t * thread, void *selfv) {
   worker_t *server;
   request_t request;
   response_t response;
+  global_t global;
 
   int write = 1;
   self_t *self = selfv;
   worker_t *client = self->client;
   
-  if ((status = worker_new(&server, "", self->log_mode, "", NULL, NULL, NULL, 
-	                   1000 * 300000, NULL)) != APR_SUCCESS) {
+  memset(&global, 0, sizeof(global));
+  global.log_mode = self->log_mode;
+  global.socktmo = 1000 * 300000;
+  
+  if ((status = worker_new(&server, "", "", &global, NULL)) != APR_SUCCESS) {
     apr_thread_exit(thread, status);
   } 
 
@@ -1141,6 +1138,7 @@ int proxy(self_t *self) {
   int off;
   const char *err;
   regex_t *compiled;
+  global_t global;
     
   if ((status = apr_threadattr_create(&tattr, self->pool)) != APR_SUCCESS) {
     return status;
@@ -1164,8 +1162,11 @@ int proxy(self_t *self) {
     return status;
   }
 
-  if ((status = worker_new(&listener, "", self->log_mode, "", NULL, NULL, NULL,
-	                   1000 * 30000, NULL)) != APR_SUCCESS) {
+  memset(&global, 0, sizeof(global));
+  global.log_mode = self->log_mode;
+  global.socktmo = 1000 * 300000;
+  
+  if ((status = worker_new(&listener, "", "", &global, NULL)) != APR_SUCCESS) {
     return status;
   } 
 
@@ -1182,9 +1183,8 @@ int proxy(self_t *self) {
 
     /* test if main is back */
     
-    if ((status = worker_new(&client, "", self->log_mode, "                        ", 
-	                     NULL, NULL, NULL, 1000 * 30000, NULL)) 
-	!= APR_SUCCESS) {
+    if ((status = worker_new(&client, "", "                        ", &global, 
+	                     NULL)) != APR_SUCCESS) {
       return status;
     } 
 
@@ -1193,9 +1193,9 @@ int proxy(self_t *self) {
     client->socket->socket = listener->socket->socket;
 
     /* new thread */
-    this = apr_pcalloc(client->pool, sizeof(*this));
+    this = apr_pcalloc(client->pbody, sizeof(*this));
     memcpy(this, self, sizeof(*this));
-    this->pool = client->pool;
+    this->pool = client->pbody;
     this->client = client;
     if (this->url_filter &&
 	(compiled = pregcomp(self->pool, this->url_filter, &err, &off))) {
